==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/PyTrilinos/src/NumPyImporter.h <==
// @HEADER
// ***********************************************************************
//
//              PyTrilinos: Python Interface to Trilinos
//                 Copyright (2005) Sandia Corporation
//
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
//
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Bill Spotz (wfspotz@sandia.gov)
//
// ***********************************************************************
// @HEADER

#ifndef NUMPYIMPORTER_H
#define NUMPYIMPORTER_H

#include "numpy_include.h"

// Singleton class that ensures that the numpy function import_array()
// gets called.

class NumPyImporter
{
protected:
  // These are protected instead of private to keep compilers happy.
  ~NumPyImporter() { }
  NumPyImporter() {import_array();}

private:
  NumPyImporter(const NumPyImporter & a_ref);
  const NumPyImporter & operator = (const NumPyImporter & a_rhs);

private:
  // The singleton, i.e. the only instance of this object is this
  // attribute
  static NumPyImporter m_singleton;
  
};

// Static initialization
NumPyImporter NumPyImporter::m_singleton;

#endif // NUMPYIMPORTER_H

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/PyTrilinos/src/NumPyImporter.h <==
// @HEADER
// ***********************************************************************
//
//              PyTrilinos: Python Interface to Trilinos
//                 Copyright (2005) Sandia Corporation
//
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
//
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Bill Spotz (wfspotz@sandia.gov)
//
// ***********************************************************************
// @HEADER

#ifndef NUMPYIMPORTER_H
#define NUMPYIMPORTER_H

#include "numpy_include.h"

// Singleton class that ensures that the numpy (macro) function
// import_array() gets called once and only once.

class NumPyImporter
{
protected:
  // These are protected instead of private to keep compilers happy.
  ~NumPyImporter() { }
  NumPyImporter() {import_array();}

private:
  NumPyImporter(const NumPyImporter & a_ref);
  const NumPyImporter & operator = (const NumPyImporter & a_rhs);

private:
  // The singleton, i.e. the only instance of this object is this
  // attribute
  static NumPyImporter m_singleton;
  
};

// Static initialization
//NumPyImporter NumPyImporter::m_singleton;

#endif // NUMPYIMPORTER_H
